Index: trunk/MagicSoft/Mars/Changelog
===================================================================
--- trunk/MagicSoft/Mars/Changelog	(revision 3839)
+++ trunk/MagicSoft/Mars/Changelog	(revision 3840)
@@ -58,4 +58,13 @@
        IsUnsuitableRun(MBadPixelsPix::kUnsuitableRun). This includes 
        now the oscillating pixels (which are sometimes many!!)
+
+   * mcalib/MHCalibrationRelTimePix.cc
+     - commented re-normalization to ns in Renorm()
+     - introduced Getter to fFADCSliceWidth
+
+   * mcalib/MHCalibrationRelTimeCam.cc
+     - renorm to ns in GetPixelsContent()
+     --> now, calibration in MCalibrateRelTimes is consistent
+
 
  2004/04/26: Abelardo Moralejo
Index: trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimePix.cc
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimePix.cc	(revision 3839)
+++ trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimePix.cc	(revision 3840)
@@ -99,4 +99,6 @@
 // If mean and sigma have not yet been set, returns.
 //
+// HAS BEEN COMMENTED IN ORDER TO ALLOW FURTHER CALIBRATION OF OFFSETS IN DATA
+// RETURNS ALWAYS WITHOUT RENORMALIZING!!
 // Results are re-normalized to a value per time (ns) with the formulae:
 //
@@ -109,4 +111,5 @@
 {
 
+  /*
   if (fMean == fMeanErr == fSigma == fSigmaErr == 0.)
     return;
@@ -116,4 +119,4 @@
   fSigma   *= fFADCSliceWidth;
   fSigmaErr*= fFADCSliceWidth;
-  
+  */
 }
Index: trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimePix.h
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimePix.h	(revision 3839)
+++ trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimePix.h	(revision 3840)
@@ -23,4 +23,7 @@
   ~MHCalibrationRelTimePix() {}
 
+  // Getters
+  Float_t GetFADCSliceWidth() const    { return fFADCSliceWidth;  }
+  
   // Setters
   void SetFADCSliceWidth( const Float_t f=fgFADCSliceWidth )  {  fFADCSliceWidth = f; }

Index: trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimeCam.cc
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimeCam.cc	(revision 3839)
+++ trunk/MagicSoft/Mars/mcalib/MHCalibrationRelTimeCam.cc	(revision 3840)
@@ -296,7 +296,7 @@
     }
   
-  const UInt_t npixels  = fGeom->GetNumPixels();
-  const UInt_t nareas   = fGeom->GetNumAreas();
-  const UInt_t nsectors = fGeom->GetNumSectors();
+  const Int_t npixels  = fGeom->GetNumPixels();
+  const Int_t nareas   = fGeom->GetNumAreas();
+  const Int_t nsectors = fGeom->GetNumSectors();
 
   Float_t sumareahi  [nareas],   sumarealo  [nareas];
@@ -349,5 +349,5 @@
     }
   
-  for (UInt_t j=0; j<nareas; j++)
+  for (Int_t j=0; j<nareas; j++)
     {
       MHGausEvents &histhi = GetAverageHiGainArea(j);
@@ -358,5 +358,5 @@
     }
   
-  for (UInt_t j=0; j<nsectors; j++)
+  for (Int_t j=0; j<nsectors; j++)
     {
       MHGausEvents &histhi = GetAverageHiGainSector(j);
@@ -422,9 +422,8 @@
 // ============== 
 //
 // 0: Fitted Mean Relative Arrival Time              (calls: MHGausEvents::GetMean())
 // 1: Error of fitted Mean Relative Arrival Time     (calls: MHGausEvents::GetMeanErr())
 // 2: Sigma of fitted Relative Arrival Time          (calls: MHGausEvents::GetSigma())
 // 3: Error of Sigma of fitted Relative Arrival Time (calls: MHGausEvents::GetSigmaErr())
 //
 //
 // Useful variables derived from the fit results:
@@ -445,27 +444,30 @@
     return kFALSE;
 
+  const MHCalibrationRelTimePix &pix = (MHCalibrationRelTimePix&)(*this)[idx];
+  const Float_t fadc2ns              = pix.GetFADCSliceWidth();
+
   switch (type)
     {
     case 0:
-      val = (*this)[idx].GetMean();
+      val = pix.GetMean()*fadc2ns;
       break;
     case 1:
-      val = (*this)[idx].GetMeanErr();
+      val = pix.GetMeanErr()*fadc2ns;
       break;
     case 2:
-      val = (*this)[idx].GetSigma();
+      val = pix.GetSigma()*fadc2ns;
       break;
     case 3:
-      val = (*this)[idx].GetSigmaErr();
+      val = pix.GetSigmaErr()*fadc2ns;
       break;
     case 4:
-      val = (*this)[idx].GetProb();
+      val = pix.GetProb();
       break;
     case 5:
-      if (!(*this)[idx].IsGausFitOK())
+      if (!pix.IsGausFitOK())
         val = 1.;
       break;
     case 6:
-      if (!(*this)[idx].IsFourierSpectrumOK())
+      if (!pix.IsFourierSpectrumOK())
         val = 1.;
       break;
@@ -422,9 +422,8 @@
 // ============== 
 //
-// 0: Fitted Mean Relative Arrival Time              (calls: MHGausEvents::GetMean())
-// 1: Error of fitted Mean Relative Arrival Time     (calls: MHGausEvents::GetMeanErr())
-// 2: Sigma of fitted Relative Arrival Time          (calls: MHGausEvents::GetSigma())
-// 3: Error of Sigma of fitted Relative Arrival Time (calls: MHGausEvents::GetSigmaErr())
-//
+// 0: Fitted Mean Relative Arrival Time in ns  (MHGausEvents::GetMean()*MHCalibrationRelTimePix::GetFADCSliceWidth())
+// 1: Error Mean Relative Arrival Time in ns   (MHGausEvents::GetMeanErr()*MHCalibrationRelTimePix::GetFADCSliceWidth())
+// 2: Sigma fitted Relative Arrival Time in ns (MHGausEvents::GetSigma()*MHCalibrationRelTimePix::GetFADCSliceWidth())
+// 3: Error Sigma Relative Arrival Time in ns  (MHGausEvents::GetSigmaErr()*MHCalibrationRelTimePix::GetFADCSliceWidth())
 //
 // Useful variables derived from the fit results: